﻿/**
 *	MiniBatteryStatus Widget
 *
 *	© Claudio Procida 2005-2008
 *
 *	Disclaimer
 *
 *	The MiniBatteryStatus Widget software (from now, the "Software") and the accompanying materials
 *	are provided “AS IS” without warranty of any kind. IN NO EVENT SHALL THE AUTHOR(S) BE
 *	LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 *	INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN
 *	IF THE AUTHOR(S) HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. The entire risk as to
 *	the results and performance of this software is assumed by you. If the software is
 *	defective, you, and not its author(s), assume the entire cost of all necessary servicing,
 *	repairs and corrections. If you do not agree to these terms and conditions, you may not
 *	install or use this software.
 */
 
function Battery()
{
	this.charge = 0;
	this.capacity = 0;
	this.maxCapacity = 0;
	this.designCapacity = 0;
	
	this.plugged = false;
	this.charging = false;

	this.manufacturer = null;
	this.manufactureDate = null;
	this.deviceName = null;
	
	this._previousCharge = 0;
	this._wasPlugged = false;
	this._wasCharging = false;
	
	this._observers = [];
}

Battery.prototype.chargeDidIncrease = function()
{
	return this.charge > this._previousCharge;
};

Battery.prototype.plugStateChanged = function()
{
	return this._wasPlugged ^ this.plugged;
};

Battery.prototype.chargingStateChanged = function()
{
	return this._wasCharging ^ this.charging;
};

Battery.prototype.toString = function()
{
	var s = "Battery {charge: " + this.charge +
		", capacity: " + this.capacity + 
		", maxCapacity: " + this.maxCapacity + 
		", designCapacity: " + this.designCapacity + 
		", manufacturer: " + this.manufacturer + 
		", manufactureDate: " + this.manufactureDate + 
		", deviceName: " + this.deviceName + 
		", plugged: " + this.plugged + 
		", charging: " + this.charging + 
		"}"; 
	return s;
};

Battery.prototype.update = function()
{
	this.charge = Plugin.charge();
	this.capacity = Plugin.capacity();
	this.maxCapacity = Plugin.maxCapacity();
	this.designCapacity = Plugin.designCapacity();
	this.manufacturer = Plugin.manufacturer();
	this.manufactureDate = Plugin.manufactureDate();
	this.deviceName = Plugin.deviceName();
	
	this.plugged = Plugin.isPlugged();
	this.charging = Plugin.isCharging();
	
	for (var i = 0; i < this._observers.length; i++)
	{
		this._observers[i](this);
	}
};

/**
 *	@method addObserver
 *	@abstract Registers a function to be called whenever the battery info did change.
 *	@param observer A callback to be called when the battery info did change.
 */
Battery.prototype.addObserver = function(observer)
{
	this._observers.push(observer);
};

/**
 *	@method removeObserver
 *	@abstract Deregisters a function previously registered as observer.
 *	@param observer A callback previously added with addObserver.
 */
Battery.prototype.removeObserver = function(observer)
{
	var pos = this._observers.indexOf(observer);
	if (pos != -1)
		this._observers.splice(pos, 1);
};

